@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** No Commercial Usage
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in 
+** accordance with the Qt Commercial License Agreement provided with
+** the Software or, alternatively, in accordance with the terms
+** contained in a written agreement between you and Nokia.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,22 +25,20 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**
-**
-**
-**
-**
-**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
-#include "DebugMacros.h"
-
 #include "s60mediaplayersession.h"
 
 #include <QtCore/qdebug.h>
@@ -50,68 +48,39 @@
 #include <mmf/common/mmferrors.h>
 #include <qmediatimerange.h>
 
-/*!
-    Construct a media playersession with the given \a parent.
-*/
-
 S60MediaPlayerSession::S60MediaPlayerSession(QObject *parent)
     : QObject(parent)
-    , m_stream(false)
     , m_playbackRate(0)
     , m_muted(false)
     , m_volume(0)
     , m_state(QMediaPlayer::StoppedState)
-    , m_mediaStatus(QMediaPlayer::NoMedia)
+    , m_mediaStatus(QMediaPlayer::UnknownMediaStatus)
     , m_progressTimer(new QTimer(this))
     , m_stalledTimer(new QTimer(this))
     , m_error(KErrNone)
     , m_play_requested(false)
+    , m_stream(false)
     , m_seekable(true)
-{
-    DP0("S60MediaPlayerSession::S60MediaPlayerSession +++");
-
+{    
     connect(m_progressTimer, SIGNAL(timeout()), this, SLOT(tick()));
     connect(m_stalledTimer, SIGNAL(timeout()), this, SLOT(stalled()));
-
-    DP0("S60MediaPlayerSession::S60MediaPlayerSession ---");
 }
 
-/*!
-    Destroys a media playersession.
-*/
-
 S60MediaPlayerSession::~S60MediaPlayerSession()
 {
-    DP0("S60MediaPlayerSession::~S60MediaPlayerSession +++");
-    DP0("S60MediaPlayerSession::~S60MediaPlayerSession ---");
 }
 
-/*!
- * \return the audio volume of a player session.
-*/
 int S60MediaPlayerSession::volume() const
 {
-    DP1("S60MediaPlayerSession::volume", m_volume);
-
     return m_volume;
 }
 
-/*!
-    Sets the audio \a volume of a player session.
-*/
-
 void S60MediaPlayerSession::setVolume(int volume)
 {
-    DP0("S60MediaPlayerSession::setVolume +++");
-
-    DP1("S60MediaPlayerSession::setVolume - ", volume);
-
     if (m_volume == volume)
         return;
     
     m_volume = volume;
-    emit volumeChanged(m_volume);
-
     // Dont set symbian players volume until media loaded.
     // Leaves with KerrNotReady although documentation says otherwise.
     if (!m_muted && 
@@ -121,43 +90,26 @@ void S60MediaPlayerSession::setVolume(int volume)
         || mediaStatus() == QMediaPlayer::BufferedMedia
         || mediaStatus() == QMediaPlayer::EndOfMedia)) {
         TRAPD(err, doSetVolumeL(m_volume));
-        setError(err);
-    }
-    DP0("S60MediaPlayerSession::setVolume ---");
-}
 
-/*!
-    \return the mute state of a player session.
-*/
+        if (KErrNone == err)
+            emit volumeChanged(m_volume);
+        else
+            setError(err);
+    }
+}
 
 bool S60MediaPlayerSession::isMuted() const
 {
-    DP1("S60MediaPlayerSession::isMuted", m_muted);
-
     return m_muted;
 }
 
-/*!
-    Identifies if the current media is seekable.
-
-    \return true if it possible to seek within the current media, and false otherwise.
-*/
-
 bool S60MediaPlayerSession::isSeekable() const
 {
-    DP1("S60MediaPlayerSession::isSeekable", m_seekable);
-
     return m_seekable;
 }
 
-/*!
-    Sets the \a status of the current media.
-*/
-
 void S60MediaPlayerSession::setMediaStatus(QMediaPlayer::MediaStatus status)
 {
-    DP0("S60MediaPlayerSession::setMediaStatus +++");
-
     if (m_mediaStatus == status)
         return;
     
@@ -167,93 +119,48 @@ void S60MediaPlayerSession::setMediaStatus(QMediaPlayer::MediaStatus status)
     
     if (m_play_requested && m_mediaStatus == QMediaPlayer::LoadedMedia)
         play();
-
-    DP0("S60MediaPlayerSession::setMediaStatus ---");
 }
 
-/*!
-    Sets the \a state on media player.
-*/
-
 void S60MediaPlayerSession::setState(QMediaPlayer::State state)
 {
-    DP0("S60MediaPlayerSession::setState +++");
-
     if (m_state == state)
         return;
     
     m_state = state;
     emit stateChanged(m_state);
-
-    DP0("S60MediaPlayerSession::setState ---");
 }
 
-/*!
-    \return the state of a player session.
-*/
-
-QMediaPlayer::State S60MediaPlayerSession::state() const
-{
-    DP1("S60MediaPlayerSession::state", m_state);
-
-    return m_state;
+QMediaPlayer::State S60MediaPlayerSession::state() const 
+{ 
+    return m_state; 
 }
 
-/*!
-    \return the status of the current media.
-*/
-
-QMediaPlayer::MediaStatus S60MediaPlayerSession::mediaStatus() const
-{
-    DP1("S60MediaPlayerSession::mediaStatus", m_mediaStatus);
-
-    return m_mediaStatus;
+QMediaPlayer::MediaStatus S60MediaPlayerSession::mediaStatus() const 
+{ 
+    return m_mediaStatus; 
 }
 
-/*!
- *  Loads the \a url for playback.
- *  If \a url is local file then it loads audio playersesion if its audio file.
- *  If it is a local video file then loads the video playersession.
-*/
-
 void S60MediaPlayerSession::load(QUrl url)
 {
-    DP0("S60MediaPlayerSession::load +++");
-
     setMediaStatus(QMediaPlayer::LoadingMedia);
     startStalledTimer();
     m_stream = (url.scheme() == "file")?false:true;
-    m_UrlPath = url;
     TRAPD(err,
         if(m_stream)
             doLoadUrlL(QString2TPtrC(url.toString()));
         else
-            doLoadL(QString2TPtrC(QDir::toNativeSeparators(QDir::cleanPath(url.toLocalFile())))));
+            doLoadL(QString2TPtrC(QDir::toNativeSeparators(url.toLocalFile()))));
     setError(err);
-
-    DP0("S60MediaPlayerSession::load ---");
 }
 
-TBool S60MediaPlayerSession::isStreaming()
-{
-    return m_stream;
-}
-
-/*!
-    Start or resume playing the current source.
-*/
 void S60MediaPlayerSession::play()
 {
-    DP0("S60MediaPlayerSession::play +++");
-
-    if ( (state() == QMediaPlayer::PlayingState && m_play_requested == false)
+    if (state() == QMediaPlayer::PlayingState
         || mediaStatus() == QMediaPlayer::UnknownMediaStatus
         || mediaStatus() == QMediaPlayer::NoMedia
         || mediaStatus() == QMediaPlayer::InvalidMedia)
         return;
 
-    setState(QMediaPlayer::PlayingState);
-
     if (mediaStatus() == QMediaPlayer::LoadingMedia ||
        (mediaStatus() == QMediaPlayer::StalledMedia &&
         state() == QMediaPlayer::StoppedState))
@@ -263,23 +170,15 @@ void S60MediaPlayerSession::play()
     }
 
     m_play_requested = false;
-    m_duration = duration();
     setVolume(m_volume);
     setMuted(m_muted);
+    setState(QMediaPlayer::PlayingState);
     startProgressTimer();
     doPlay();
-
-    DP0("S60MediaPlayerSession::play ---");
 }
 
-/*!
-    Pause playing the current source.
-*/
-
 void S60MediaPlayerSession::pause()
 {
-    DP0("S60MediaPlayerSession::pause +++");
-
     if (state() != QMediaPlayer::PlayingState)
         return;
 
@@ -290,19 +189,10 @@ void S60MediaPlayerSession::pause()
     setState(QMediaPlayer::PausedState);
     stopProgressTimer();
     TRAP_IGNORE(doPauseL());
-    m_play_requested = false;
-
-    DP0("S60MediaPlayerSession::pause ---");
 }
 
-/*!
-    Stop playing, and reset the play position to the beginning.
-*/
-
 void S60MediaPlayerSession::stop()
 {
-    DP0("S60MediaPlayerSession::stop +++");
-
     if (state() == QMediaPlayer::StoppedState)
         return;
 
@@ -318,20 +208,11 @@ void S60MediaPlayerSession::stop()
     stopStalledTimer();
     doStop();
     emit positionChanged(0);
-
-    DP0("S60MediaPlayerSession::stop ---");
 }
 
-/*!
- * Stops the playback and closes the controllers.
- * And resets all the flags and status, state to default values.
-*/
-
 void S60MediaPlayerSession::reset()
 {
-    DP0("S60MediaPlayerSession::reset +++");
-
-    m_play_requested = false;
+    m_play_requested = false;    
     setError(KErrNone, QString(), true);
     stopProgressTimer();
     stopStalledTimer();
@@ -339,39 +220,15 @@ void S60MediaPlayerSession::reset()
     doClose();
     setState(QMediaPlayer::StoppedState);
     setMediaStatus(QMediaPlayer::UnknownMediaStatus);
-    setPosition(0);
-
-    DP0("S60MediaPlayerSession::reset ---");
 }
 
-/*!
- * Sets \a renderer as video renderer.
-*/
-
 void S60MediaPlayerSession::setVideoRenderer(QObject *renderer)
 {
-    DP0("S60MediaPlayerSession::setVideoRenderer +++");
-
     Q_UNUSED(renderer);
-
-    DP0("S60MediaPlayerSession::setVideoRenderer ---");
 }
 
-/*!
- *   the percentage of the temporary buffer filled before playback begins.
-
-    When the player object is buffering; this property holds the percentage of
-    the temporary buffer that is filled. The buffer will need to reach 100%
-    filled before playback can resume, at which time the MediaStatus will be
-    BufferedMedia.
-
-    \sa mediaStatus()
-*/
-
 int S60MediaPlayerSession::bufferStatus()
 {
-    DP0("S60MediaPlayerSession::bufferStatus");
-
     if (state() ==QMediaPlayer::StoppedState)
         return 0;
 
@@ -392,46 +249,23 @@ int S60MediaPlayerSession::bufferStatus()
     return progress;
 }
 
-/*!
- * return TRUE if Meta data is available in current media source.
-*/
-
 bool S60MediaPlayerSession::isMetadataAvailable() const
 {
-    DP0("S60MediaPlayerSession::isMetadataAvailable");
-
-    return !m_metaDataMap.isEmpty();
+    return !m_metaDataMap.isEmpty();    
 }
 
-/*!
- * \return the \a key meta data.
-*/
 QVariant S60MediaPlayerSession::metaData(const QString &key) const
 {
-    DP0("S60MediaPlayerSession::metaData (const QString &key) const");
-
-    return m_metaDataMap.value(key);
+    return m_metaDataMap.value(key);    
 }
 
-/*!
- * \return the \a key meta data as QString.
-*/
-
 QVariant S60MediaPlayerSession::metaData(QtMultimediaKit::MetaData key) const
 {
-    DP0("S60MediaPlayerSession::metaData (QtMultimediaKit::MetaData key) const");
-
     return metaData(metaDataKeyAsString(key));
 }
 
-/*!
- * \return List of all available meta data from current media source.
-*/
-
 QList<QtMultimediaKit::MetaData> S60MediaPlayerSession::availableMetaData() const
 {
-    DP0("S60MediaPlayerSession::availableMetaData +++");
-
     QList<QtMultimediaKit::MetaData> metaDataTags;
     if (isMetadataAvailable()) {
         for (int i = QtMultimediaKit::Title; i <= QtMultimediaKit::ThumbnailImage; i++) {
@@ -443,31 +277,16 @@ QList<QtMultimediaKit::MetaData> S60MediaPlayerSession::availableMetaData() cons
             }
         }
     }
-
-    DP0("S60MediaPlayerSession::availableMetaData ---");
-
     return metaDataTags;
 }
 
-/*!
- * \return all available extended meta data of current media source.
-*/
-
 QStringList S60MediaPlayerSession::availableExtendedMetaData() const
 {
-    DP0("S60MediaPlayerSession::availableExtendedMetaData");
-
     return m_metaDataMap.keys();
 }
 
-/*!
- * \return meta data \a key as QString.
-*/
-
 QString S60MediaPlayerSession::metaDataKeyAsString(QtMultimediaKit::MetaData key) const
 {
-    DP1("S60MediaPlayerSession::metaDataKeyAsString", key);
-
     switch(key) {
     case QtMultimediaKit::Title: return "title";
     case QtMultimediaKit::AlbumArtist: return "artist";
@@ -527,37 +346,25 @@ QString S60MediaPlayerSession::metaDataKeyAsString(QtMultimediaKit::MetaData key
     return QString();
 }
 
-/*!
-    Sets the \a muted state of a player session.
-*/
-
 void S60MediaPlayerSession::setMuted(bool muted)
 {
-    DP0("S60MediaPlayerSession::setMuted +++");
-    DP1("S60MediaPlayerSession::setMuted - ", muted);
-
     m_muted = muted;
-    emit mutedChanged(m_muted);
-
+    
     if(   m_mediaStatus == QMediaPlayer::LoadedMedia 
        || (m_mediaStatus == QMediaPlayer::StalledMedia && state() != QMediaPlayer::StoppedState)
        || m_mediaStatus == QMediaPlayer::BufferingMedia
        || m_mediaStatus == QMediaPlayer::BufferedMedia
        || m_mediaStatus == QMediaPlayer::EndOfMedia) {
         TRAPD(err, doSetVolumeL((m_muted)?0:m_volume));
-        setError(err);
+        if (KErrNone == err)
+            emit mutedChanged(m_muted);
+        else
+            setError(err);
     }
-    DP0("S60MediaPlayerSession::setMuted ---");
 }
 
-/*!
-   \return the duration of the current media in milliseconds.
-*/
-
 qint64 S60MediaPlayerSession::duration() const
 {
-  //  DP0("S60MediaPlayerSession::duration");
-
     if(   mediaStatus() == QMediaPlayer::LoadingMedia
        || mediaStatus() == QMediaPlayer::UnknownMediaStatus
        || mediaStatus() == QMediaPlayer::NoMedia
@@ -570,14 +377,8 @@ qint64 S60MediaPlayerSession::duration() const
     return pos;
 }
 
-/*!
-    \return the current playback position in milliseconds.
-*/
-
 qint64 S60MediaPlayerSession::position() const
 {
- //   DP0("S60MediaPlayerSession::position");
-
     if(   mediaStatus() == QMediaPlayer::LoadingMedia
        || mediaStatus() == QMediaPlayer::UnknownMediaStatus
        || mediaStatus() == QMediaPlayer::NoMedia
@@ -587,23 +388,11 @@ qint64 S60MediaPlayerSession::position() const
     
     qint64 pos = 0;
     TRAP_IGNORE(pos = doGetPositionL());
-    if (!m_play_requested && pos ==0
-        && mediaStatus() != QMediaPlayer::LoadedMedia)
-        return m_duration;
     return pos;
 }
 
-/*!
-    Sets the playback \a pos of the current media.  This will initiate a seek and it may take
-    some time for playback to reach the position set.
-*/
-
 void S60MediaPlayerSession::setPosition(qint64 pos)
 {
-    DP0("S60MediaPlayerSession::setPosition +++");
-
-    DP1("S60MediaPlayerSession::setPosition - ", pos);
-
     if (position() == pos)
         return;
 
@@ -615,11 +404,7 @@ void S60MediaPlayerSession::setPosition(qint64 pos)
     TRAPD(err, doSetPositionL(pos * 1000));
     setError(err);
 
-    if (err == KErrNone) {
-        if (mediaStatus() == QMediaPlayer::EndOfMedia)
-            setMediaStatus(QMediaPlayer::LoadedMedia);
-    }
-    else if (err == KErrNotSupported) {
+    if (err == KErrNotSupported) {
         m_seekable = false;
         emit seekableChanged(m_seekable);
     }
@@ -628,143 +413,63 @@ void S60MediaPlayerSession::setPosition(qint64 pos)
         play();
 
     emit positionChanged(position());
-
-    DP0("S60MediaPlayerSession::setPosition ---");
 }
 
-/*!
- * Set the audio endpoint to \a audioEndpoint.
-*/
-
 void S60MediaPlayerSession::setAudioEndpoint(const QString& audioEndpoint)
 {
-    DP0("S60MediaPlayerSession::setAudioEndpoint +++");
-
-    DP1("S60MediaPlayerSession::setAudioEndpoint - ", audioEndpoint);
-
     doSetAudioEndpoint(audioEndpoint);
-
-    DP0("S60MediaPlayerSession::setAudioEndpoint ---");
 }
 
-/*!
- * Loading of media source is completed.
- * And ready for playback. Updates all the media status, state, settings etc.
- * And emits the signals.
-*/
-
 void S60MediaPlayerSession::loaded()
 {
-    DP0("S60MediaPlayerSession::loaded +++");
-
     stopStalledTimer();
     if (m_error == KErrNone || m_error == KErrMMPartialPlayback) {
         setMediaStatus(QMediaPlayer::LoadedMedia);
         TRAPD(err, updateMetaDataEntriesL());
         setError(err);
         emit durationChanged(duration());
-        emit positionChanged(0);
         emit videoAvailableChanged(isVideoAvailable());
         emit audioAvailableChanged(isAudioAvailable());
         emit mediaChanged();
 
         m_seekable = getIsSeekable();
     }
-
-    DP0("S60MediaPlayerSession::loaded ---");
 }
 
-/*!
- * Playback is completed as medai source reached end of media.
-*/
 void S60MediaPlayerSession::endOfMedia()
 {
-    DP0("S60MediaPlayerSession::endOfMedia +++");
-
     m_state = QMediaPlayer::StoppedState;
     setMediaStatus(QMediaPlayer::EndOfMedia);
     //there is a chance that user might have called play from EOF callback
     //if we are already in playing state, do not send state change callback
     if(m_state == QMediaPlayer::StoppedState)
         emit stateChanged(QMediaPlayer::StoppedState);
-    emit positionChanged(m_duration);
-
-    DP0("S60MediaPlayerSession::endOfMedia ---");
+    emit positionChanged(0);
 }
 
-/*!
- *  The percentage of the temporary buffer filling before playback begins.
-
-    When the player object is buffering; this property holds the percentage of
-    the temporary buffer that is filled. The buffer will need to reach 100%
-    filled before playback can resume, at which time the MediaStatus will be
-    BufferedMedia.
-
-    \sa mediaStatus()
-*/
-
 void S60MediaPlayerSession::buffering()
 {
-    DP0("S60MediaPlayerSession::buffering +++");
-
     startStalledTimer();
     setMediaStatus(QMediaPlayer::BufferingMedia);
-
-//Buffering cannot happen in stopped state. Hence update the state
-    if (state() == QMediaPlayer::StoppedState)
-        setState(QMediaPlayer::PausedState);
-
-    DP0("S60MediaPlayerSession::buffering ---");
 }
 
-/*!
- * Buffer is filled with data and to for continuing/start playback.
-*/
-
 void S60MediaPlayerSession::buffered()
 {
-    DP0("S60MediaPlayerSession::buffered +++");
-
     stopStalledTimer();
     setMediaStatus(QMediaPlayer::BufferedMedia);
-
-    DP0("S60MediaPlayerSession::buffered ---");
 }
-
-/*!
- * Sets media status as stalled as waiting for the buffer to be filled to start playback.
-*/
-
 void S60MediaPlayerSession::stalled()
 {
-    DP0("S60MediaPlayerSession::stalled +++");
-
     setMediaStatus(QMediaPlayer::StalledMedia);
-
-    DP0("S60MediaPlayerSession::stalled ---");
 }
 
-/*!
- * \return all the meta data entries in the current media source.
-*/
-
 QMap<QString, QVariant>& S60MediaPlayerSession::metaDataEntries()
 {
-    DP0("S60MediaPlayerSession::metaDataEntries");
-
     return m_metaDataMap;
 }
 
-/*!
- * \return Error by converting Symbian specific error to Multimedia error.
-*/
-
 QMediaPlayer::Error S60MediaPlayerSession::fromSymbianErrorToMultimediaError(int error)
 {
-    DP0("S60MediaPlayerSession::fromSymbianErrorToMultimediaError");
-
-    DP1("S60MediaPlayerSession::fromSymbianErrorToMultimediaError - ", error);
-
     switch(error) {
         case KErrNoMemory:
         case KErrNotFound:
@@ -780,8 +485,6 @@ QMediaPlayer::Error S60MediaPlayerSession::fromSymbianErrorToMultimediaError(int
         case KErrServerBusy:
         case KErrCompletion:  
         case KErrBadPower:    
-        case KErrMMInvalidProtocol:
-        case KErrMMInvalidURL:
             return QMediaPlayer::ResourceError;
         
         case KErrMMPartialPlayback:   
@@ -800,6 +503,8 @@ QMediaPlayer::Error S60MediaPlayerSession::fromSymbianErrorToMultimediaError(int
         case KErrMMServerSocket:
         case KErrMMServerNotSupported:
         case KErrMMUDPReceive:
+        case KErrMMInvalidProtocol:
+        case KErrMMInvalidURL:
         case KErrMMMulticast:
         case KErrMMProxyServer:
         case KErrMMProxyServerNotSupported:
@@ -825,29 +530,13 @@ QMediaPlayer::Error S60MediaPlayerSession::fromSymbianErrorToMultimediaError(int
     }
 }
 
-/*!
- * \return error.
- */
-
 int S60MediaPlayerSession::error() const
 {
-    DP1("S60MediaPlayerSession::error", m_error);
-
     return m_error;
 }
 
-/*!
- * Sets the error.
- * * If playback complete/prepare complete ..., etc with successful then sets error as ZERO
- *  else Multimedia error.
-*/
-
 void S60MediaPlayerSession::setError(int error, const QString &errorString, bool forceReset)
 {
-    DP0("S60MediaPlayerSession::setError +++");
-
-    DP5("S60MediaPlayerSession::setError - error:", error,"errorString:", errorString, "forceReset:", forceReset);
-
     if( forceReset ) {
         m_error = KErrNone;
         emit this->error(QMediaPlayer::NoError, QString());
@@ -872,9 +561,7 @@ void S60MediaPlayerSession::setError(int error, const QString &errorString, bool
 
     emit this->error(mediaError, symbianError);
 
-    if (m_error == KErrInUse) {
-        pause();
-    } else if (mediaError != QMediaPlayer::NoError) {
+    if (mediaError !=QMediaPlayer::NoError) {
         m_play_requested = false;
         setMediaStatus(QMediaPlayer::InvalidMedia);
         stop();
@@ -889,164 +576,53 @@ void S60MediaPlayerSession::setAndEmitError(int error)
     symbianError.append("Symbian:");
     symbianError.append(QString::number(error));
     emit this->error(rateError, symbianError);
-
-    DP0("S60MediaPlayerSession::setError ---");
 }
 
-/*!
- * emits the signal if there is a changes in position and buffering status.
- */
-
 void S60MediaPlayerSession::tick()
 {
-    DP0("S60MediaPlayerSession::tick +++");
-
     emit positionChanged(position());
 
     if (bufferStatus() < 100)
         emit bufferStatusChanged(bufferStatus());
-
-    DP0("S60MediaPlayerSession::tick ---");
 }
 
-/*!
- * Starts the timer once the media source starts buffering.
-*/
-
 void S60MediaPlayerSession::startProgressTimer()
 {
-    DP0("S60MediaPlayerSession::startProgressTimer +++");
-
     m_progressTimer->start(500);
-
-    DP0("S60MediaPlayerSession::startProgressTimer ---");
 }
 
-/*!
- * Stops the timer once the media source finished buffering.
-*/
-
 void S60MediaPlayerSession::stopProgressTimer()
 {
-    DP0("S60MediaPlayerSession::stopProgressTimer +++");
-
     m_progressTimer->stop();
-
-    DP0("S60MediaPlayerSession::stopProgressTimer ---");
 }
 
-/*!
- * Starts the timer while waiting for some events to happen like source buffering or call backs etc.
- * So that if the events doesn't occur before stalled timer stops, it'll set the error/media status etc.
-*/
-
 void S60MediaPlayerSession::startStalledTimer()
 {
-    DP0("S60MediaPlayerSession::startStalledTimer +++");
-
     m_stalledTimer->start(30000);
-
-    DP0("S60MediaPlayerSession::startStalledTimer ---");
 }
 
-/*!
- *  Stops the timer when some events occurred while waiting for them.
- *  media source started buffering or call back is received etc.
-*/
-
 void S60MediaPlayerSession::stopStalledTimer()
 {
-    DP0("S60MediaPlayerSession::stopStalledTimer +++");
-
     m_stalledTimer->stop();
-
-    DP0("S60MediaPlayerSession::stopStalledTimer ---");
 }
 
-/*!
- * \return Converted Symbian specific Descriptor to QString.
-*/
-
 QString S60MediaPlayerSession::TDesC2QString(const TDesC& aDescriptor)
 {
-    DP0("S60MediaPlayerSession::TDesC2QString");
-
     return QString::fromUtf16(aDescriptor.Ptr(), aDescriptor.Length());
 }
 
-/*!
- * \return Converted QString to non-modifiable pointer Descriptor.
-*/
-
 TPtrC S60MediaPlayerSession::QString2TPtrC( const QString& string )
 {
-    DP0("S60MediaPlayerSession::QString2TPtrC");
-
 	// Returned TPtrC is valid as long as the given parameter is valid and unmodified
     return TPtrC16(static_cast<const TUint16*>(string.utf16()), string.length());
 }
 
-/*!
- * \return Converted Symbian TRect object to QRect object.
-*/
-
 QRect S60MediaPlayerSession::TRect2QRect(const TRect& tr)
 {
-    DP0("S60MediaPlayerSession::TRect2QRect");
-
     return QRect(tr.iTl.iX, tr.iTl.iY, tr.Width(), tr.Height());
 }
 
-/*!
- * \return converted QRect object to Symbian specific TRec object.
- */
-
 TRect S60MediaPlayerSession::QRect2TRect(const QRect& qr)
 {
-    DP0("S60MediaPlayerSession::QRect2TRect");
-
     return TRect(TPoint(qr.left(), qr.top()), TSize(qr.width(), qr.height()));
 }
-
-/*!
-    \fn bool S60MediaPlayerSession::isVideoAvailable();
-
-
-    Returns TRUE if Video is available.
-*/
-
-/*!
-    \fn bool S60MediaPlayerSession::isAudioAvailable();
-
-
-    Returns TRUE if Audio is available.
-*/
-
-/*!
-    \fn void S60MediaPlayerSession::setPlaybackRate (qreal rate);
-
-
-    Sets \a rate play back rate on media source. getIsSeekable
-*/
-
-/*!
-    \fn bool S60MediaPlayerSession::getIsSeekable () const;
-
-
-    \return TRUE if Seekable possible on current media source else FALSE.
-*/
-
-/*!
-    \fn QString S60MediaPlayerSession::activeEndpoint () const;
-
-
-    \return active end point name..
-*/
-
-/*!
-    \fn QString S60MediaPlayerSession::defaultEndpoint () const;
-
-
-    \return default end point name.
-*/
-
