@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** No Commercial Usage
-** This file contains pre-release code and may not be distributed.
-** You may use this file in accordance with the terms and conditions
-** contained in the Technology Preview License Agreement accompanying
-** this package.
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in 
+** accordance with the Qt Commercial License Agreement provided with
+** the Software or, alternatively, in accordance with the terms
+** contained in a written agreement between you and Nokia.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** If you have questions regarding the use of this file, please contact
-** Nokia at qt-info@nokia.com.
-**
-**
-**
-**
-**
-**
-**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
+** If you are unsure which license is appropriate for your use, please
+** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -219,7 +219,6 @@ public:
 
     \ingroup gallery
     \ingroup gallery-filters
-    \since 1.1
 
     \inmodule QtGallery
 
@@ -239,7 +238,6 @@ public:
 
 /*!
     Constructs an empty intersection.
-    \since 1.1
 */
 
 QGalleryIntersectionFilter::QGalleryIntersectionFilter()
@@ -249,7 +247,6 @@ QGalleryIntersectionFilter::QGalleryIntersectionFilter()
 
 /*!
     Constructs an intersection filter from a meta-data \a filter.
-    \since 1.1
 */
 
 QGalleryIntersectionFilter::QGalleryIntersectionFilter(const QGalleryMetaDataFilter &filter)
@@ -260,7 +257,6 @@ QGalleryIntersectionFilter::QGalleryIntersectionFilter(const QGalleryMetaDataFil
 
 /*!
     Constructs an intersection filter from a union \a filter.
-    \since 1.1
 */
 
 QGalleryIntersectionFilter::QGalleryIntersectionFilter(const QGalleryUnionFilter &filter)
@@ -271,7 +267,6 @@ QGalleryIntersectionFilter::QGalleryIntersectionFilter(const QGalleryUnionFilter
 
 /*!
     Constructs a copy of an intersection \a filter.
-    \since 1.1
 */
 
 QGalleryIntersectionFilter::QGalleryIntersectionFilter(const QGalleryIntersectionFilter &filter)
@@ -307,7 +302,6 @@ QGalleryIntersectionFilter::~QGalleryIntersectionFilter()
 
 /*!
     Assigns the value of \a filter to another intersection filter.
-    \since 1.1
 */
 
 QGalleryIntersectionFilter &QGalleryIntersectionFilter::operator =(
@@ -324,7 +318,6 @@ QGalleryIntersectionFilter &QGalleryIntersectionFilter::operator =(
     An invalid filter can be obtained by casting a non
     QGalleryFilter::Intersection type QGalleryFilter to
     QGalleryIntersectionFilter.
-    \since 1.1
 */
 
 bool QGalleryIntersectionFilter::isValid() const
@@ -334,7 +327,6 @@ bool QGalleryIntersectionFilter::isValid() const
 
 /*!
     Returns the number of filters in an intersection.
-    \since 1.1
 */
 
 int QGalleryIntersectionFilter::filterCount() const
@@ -345,7 +337,6 @@ int QGalleryIntersectionFilter::filterCount() const
 /*!
     Returns true if an intersection does not contain any filters, and returns
     false otherwise.
-    \since 1.1
 */
 
 bool QGalleryIntersectionFilter::isEmpty() const
@@ -355,7 +346,6 @@ bool QGalleryIntersectionFilter::isEmpty() const
 
 /*!
     Return the filters contained in an intersection.
-    \since 1.1
 */
 
 QList<QGalleryFilter> QGalleryIntersectionFilter::filters() const
@@ -365,7 +355,6 @@ QList<QGalleryFilter> QGalleryIntersectionFilter::filters() const
 
 /*!
     Appends a meta-data \a filter to an intersection.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::append(const QGalleryMetaDataFilter &filter)
@@ -375,7 +364,6 @@ void QGalleryIntersectionFilter::append(const QGalleryMetaDataFilter &filter)
 
 /*!
     Appens a union \a filter to an intersection.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::append(const QGalleryUnionFilter &filter)
@@ -385,7 +373,6 @@ void QGalleryIntersectionFilter::append(const QGalleryUnionFilter &filter)
 
 /*!
     Appends the contents of an intersection \a filter to an intersection.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::append(const QGalleryIntersectionFilter &filter)
@@ -395,7 +382,6 @@ void QGalleryIntersectionFilter::append(const QGalleryIntersectionFilter &filter
 
 /*!
     Prepends a meta-data \a filter to an intersection.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::prepend(const QGalleryMetaDataFilter &filter)
@@ -405,7 +391,6 @@ void QGalleryIntersectionFilter::prepend(const QGalleryMetaDataFilter &filter)
 
 /*!
     Prepends a union \a filter to an intersection.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::prepend(const QGalleryUnionFilter &filter)
@@ -415,7 +400,6 @@ void QGalleryIntersectionFilter::prepend(const QGalleryUnionFilter &filter)
 
 /*!
     Prepends the contents of an intersection \a filter to an intersection.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::prepend(const QGalleryIntersectionFilter &filter)
@@ -425,7 +409,6 @@ void QGalleryIntersectionFilter::prepend(const QGalleryIntersectionFilter &filte
 
 /*!
     Inserts a meta-data \a filter into an intersection at \a index.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::insert(int index, const QGalleryMetaDataFilter &filter)
@@ -435,7 +418,6 @@ void QGalleryIntersectionFilter::insert(int index, const QGalleryMetaDataFilter
 
 /*!
     Inserts a union \a filter into an intersection at \a index.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::insert(int index, const QGalleryUnionFilter &filter)
@@ -446,7 +428,6 @@ void QGalleryIntersectionFilter::insert(int index, const QGalleryUnionFilter &fi
 /*!
     Inserts the contents of an intersection  \a filter into an intersection at
     \a index.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::insert(int index, const QGalleryIntersectionFilter &filter)
@@ -460,7 +441,6 @@ void QGalleryIntersectionFilter::insert(int index, const QGalleryIntersectionFil
 /*!
     Replaces the filter at \a index in an intersection with a meta-data
     \a filter.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::replace(int index, const QGalleryMetaDataFilter &filter)
@@ -471,7 +451,6 @@ void QGalleryIntersectionFilter::replace(int index, const QGalleryMetaDataFilter
 /*!
     Replaces the filter at \a index in an intersection with a union
     \a filter.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::replace(int index, const QGalleryUnionFilter &filter)
@@ -481,7 +460,6 @@ void QGalleryIntersectionFilter::replace(int index, const QGalleryUnionFilter &f
 
 /*!
     Removes the filter at \a index from an intersection.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::remove(int index)
@@ -491,7 +469,6 @@ void QGalleryIntersectionFilter::remove(int index)
 
 /*!
     Clears all the filters from an intersection.
-    \since 1.1
 */
 
 void QGalleryIntersectionFilter::clear()
@@ -501,7 +478,6 @@ void QGalleryIntersectionFilter::clear()
 
 /*!
     Appends a \a filter to an intersection.
-    \since 1.1
 */
 
 QGalleryIntersectionFilter &QGalleryIntersectionFilter::operator <<(
@@ -519,7 +495,6 @@ QGalleryIntersectionFilter &QGalleryIntersectionFilter::operator <<(
     \a filter2.
 
     \relates QGalleryIntersectionFilter
-    \since 1.1
 */
 
 QGalleryIntersectionFilter operator &&(
@@ -535,7 +510,6 @@ QGalleryIntersectionFilter operator &&(
 
     \ingroup gallery
     \ingroup gallery-filters
-    \since 1.1
 
     \inmodule QtGallery
 
@@ -554,7 +528,6 @@ QGalleryIntersectionFilter operator &&(
 
 /*!
     Constructs an empty union.
-    \since 1.1
 */
 
 QGalleryUnionFilter::QGalleryUnionFilter()
@@ -564,7 +537,6 @@ QGalleryUnionFilter::QGalleryUnionFilter()
 
 /*!
     Constructs a union filter from a meta data \a filter.
-    \since 1.1
 */
 
 QGalleryUnionFilter::QGalleryUnionFilter(const QGalleryMetaDataFilter &filter)
@@ -575,7 +547,6 @@ QGalleryUnionFilter::QGalleryUnionFilter(const QGalleryMetaDataFilter &filter)
 
 /*!
     Constructs a union filter from an intersection \a filter.
-    \since 1.1
 */
 
 QGalleryUnionFilter::QGalleryUnionFilter(const QGalleryIntersectionFilter &filter)
@@ -586,7 +557,6 @@ QGalleryUnionFilter::QGalleryUnionFilter(const QGalleryIntersectionFilter &filte
 
 /*!
     Constructs a copy of a union \a filter.
-    \since 1.1
 */
 
 QGalleryUnionFilter::QGalleryUnionFilter(const QGalleryUnionFilter &filter)
@@ -622,7 +592,6 @@ QGalleryUnionFilter::~QGalleryUnionFilter()
 
 /*!
     Assigns the value of \a filter to another union filter.
-    \since 1.1
 */
 
 QGalleryUnionFilter &QGalleryUnionFilter::operator =(const QGalleryUnionFilter &filter)
@@ -637,7 +606,6 @@ QGalleryUnionFilter &QGalleryUnionFilter::operator =(const QGalleryUnionFilter &
 
     An invalid filter can be obtained by casting a non QGalleryFilter::Union
     type QGalleryFilter to QGalleryUnionFilter.
-    \since 1.1
 */
 
 bool QGalleryUnionFilter::isValid() const
@@ -647,7 +615,6 @@ bool QGalleryUnionFilter::isValid() const
 
 /*!
     Returns the number of filters in a union.
-    \since 1.1
 */
 
 int QGalleryUnionFilter::filterCount() const
@@ -657,7 +624,6 @@ int QGalleryUnionFilter::filterCount() const
 
 /*!
     Returns true if a union contains no filters, and false otherwise.
-    \since 1.1
 */
 
 bool QGalleryUnionFilter::isEmpty() const
@@ -667,7 +633,6 @@ bool QGalleryUnionFilter::isEmpty() const
 
 /*!
     Returns the filters contained in a union.
-    \since 1.1
 */
 
 QList<QGalleryFilter> QGalleryUnionFilter::filters() const
@@ -677,7 +642,6 @@ QList<QGalleryFilter> QGalleryUnionFilter::filters() const
 
 /*!
     Appends a meta-data \a filter to a union.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::append(const QGalleryMetaDataFilter &filter)
@@ -687,7 +651,6 @@ void QGalleryUnionFilter::append(const QGalleryMetaDataFilter &filter)
 
 /*!
     Appends an intersection \a filter to a union.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::append(const QGalleryIntersectionFilter &filter)
@@ -697,7 +660,6 @@ void QGalleryUnionFilter::append(const QGalleryIntersectionFilter &filter)
 
 /*!
     Appends the contents of a union \a filter to a union.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::append(const QGalleryUnionFilter &filter)
@@ -707,7 +669,6 @@ void QGalleryUnionFilter::append(const QGalleryUnionFilter &filter)
 
 /*!
     Prepends a meta-data \a filter to a union.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::prepend(const QGalleryMetaDataFilter &filter)
@@ -717,7 +678,6 @@ void QGalleryUnionFilter::prepend(const QGalleryMetaDataFilter &filter)
 
 /*!
     Prepends an intersection \a filter to a union.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::prepend(const QGalleryIntersectionFilter &filter)
@@ -727,7 +687,6 @@ void QGalleryUnionFilter::prepend(const QGalleryIntersectionFilter &filter)
 
 /*!
     Prepends the contents of a union \a filter to a union.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::prepend(const QGalleryUnionFilter &filter)
@@ -737,7 +696,6 @@ void QGalleryUnionFilter::prepend(const QGalleryUnionFilter &filter)
 
 /*!
     Inserts a meta-data \a filter into a union at \a index.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::insert(int index, const QGalleryMetaDataFilter &filter)
@@ -747,7 +705,6 @@ void QGalleryUnionFilter::insert(int index, const QGalleryMetaDataFilter &filter
 
 /*!
     Inserts an intersection \a filter into a union at \a index.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::insert(int index, const QGalleryIntersectionFilter &filter)
@@ -757,7 +714,6 @@ void QGalleryUnionFilter::insert(int index, const QGalleryIntersectionFilter &fi
 
 /*!
     Inserts the contents of a union \a filter into a union at \a index.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::insert(int index, const QGalleryUnionFilter &filter)
@@ -770,7 +726,6 @@ void QGalleryUnionFilter::insert(int index, const QGalleryUnionFilter &filter)
 
 /*!
     Replaces the filter at \a index in a union with a meta-data \a filter.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::replace(int index, const QGalleryMetaDataFilter &filter)
@@ -780,7 +735,6 @@ void QGalleryUnionFilter::replace(int index, const QGalleryMetaDataFilter &filte
 
 /*!
     Replaces the filter at \a index in a union with an intersetion \a filter.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::replace(int index, const QGalleryIntersectionFilter &filter)
@@ -790,7 +744,6 @@ void QGalleryUnionFilter::replace(int index, const QGalleryIntersectionFilter &f
 
 /*!
     Removes the filter at \a index from a union.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::remove(int index)
@@ -800,7 +753,6 @@ void QGalleryUnionFilter::remove(int index)
 
 /*!
     Clears all the filters from a union.
-    \since 1.1
 */
 
 void QGalleryUnionFilter::clear()
@@ -810,7 +762,6 @@ void QGalleryUnionFilter::clear()
 
 /*!
     Appends a \a filter to a union.
-    \since 1.1
 */
 
 QGalleryUnionFilter &QGalleryUnionFilter::operator <<(const QGalleryUnionFilter &filter)
@@ -827,7 +778,6 @@ QGalleryUnionFilter &QGalleryUnionFilter::operator <<(const QGalleryUnionFilter
     \a filter2.
 
     \relates QGalleryUnionFilter
-    \since 1.1
 */
 
 QGalleryUnionFilter operator ||(
@@ -845,7 +795,6 @@ QGalleryUnionFilter operator ||(
     \ingroup gallery-filters
 
     \inmodule QtGallery
-    \since 1.1
 
     \brief The QGalleryMetaDataFilter class provides a filter which accepts
     items with meta-data properties matching a specific value.
@@ -875,7 +824,6 @@ QGalleryMetaDataFilter::QGalleryMetaDataFilter()
 /*!
     Constructs a meta-data filter which tests if a meta-data \a property
     matches a \a value according to a \a comparison operator.
-    \since 1.1
 */
 
 QGalleryMetaDataFilter::QGalleryMetaDataFilter(
@@ -891,7 +839,6 @@ QGalleryMetaDataFilter::QGalleryMetaDataFilter(
 
 /*!
     Constructs a copy of a meta-data \a filter.
-    \since 1.1
 */
 
 QGalleryMetaDataFilter::QGalleryMetaDataFilter(const QGalleryMetaDataFilter &filter)
@@ -927,7 +874,6 @@ QGalleryMetaDataFilter::~QGalleryMetaDataFilter()
 
 /*!
     Assigns the value of \a filter to another meta-data filter.
-    \since 1.1
 */
 
 QGalleryMetaDataFilter &QGalleryMetaDataFilter::operator =(const QGalleryMetaDataFilter &filter)
@@ -942,7 +888,6 @@ QGalleryMetaDataFilter &QGalleryMetaDataFilter::operator =(const QGalleryMetaDat
 
     An invalid filter can be obtained by casting a non QGalleryFilter::MetaData
     type QGalleryFilter to QGalleryMetaDataFilter.
-    \since 1.1
 */
 
 bool QGalleryMetaDataFilter::isValid() const
@@ -953,7 +898,6 @@ bool QGalleryMetaDataFilter::isValid() const
 /*!
     Returns the name of the property the value of a meta-data filter is
     compared against.
-    \since 1.1
 */
 
 QString QGalleryMetaDataFilter::propertyName() const
@@ -964,7 +908,6 @@ QString QGalleryMetaDataFilter::propertyName() const
 /*!
     Sets the \a name of the property the value of meta-data filter is compared
     against.
-    \since 1.1
 */
 
 void QGalleryMetaDataFilter::setPropertyName(const QString &name)
@@ -975,7 +918,6 @@ void QGalleryMetaDataFilter::setPropertyName(const QString &name)
 /*!
     Returns the value a property is expected to match for a meta-data filter to
     pass.
-    \since 1.1
 */
 
 QVariant QGalleryMetaDataFilter::value() const
@@ -986,7 +928,6 @@ QVariant QGalleryMetaDataFilter::value() const
 /*!
     Sets the \a value a property is expected to match for a meta-data filter to
     pass.
-    \since 1.1
 */
 
 void QGalleryMetaDataFilter::setValue(const QVariant &value)
@@ -996,7 +937,6 @@ void QGalleryMetaDataFilter::setValue(const QVariant &value)
 
 /*!
     Returns the comparator used by a meta-data filter.
-    \since 1.1
 */
 
 QGalleryFilter::Comparator QGalleryMetaDataFilter::comparator() const
@@ -1006,7 +946,6 @@ QGalleryFilter::Comparator QGalleryMetaDataFilter::comparator() const
 
 /*!
     Sets the \a comparator used by a meta-data filter.
-    \since 1.1
 */
 
 void QGalleryMetaDataFilter::setComparator(QGalleryFilter::Comparator comparator)
@@ -1016,7 +955,6 @@ void QGalleryMetaDataFilter::setComparator(QGalleryFilter::Comparator comparator
 
 /*!
     Returns whether the result of a meta-data filter should be negated.
-    \since 1.1
 */
 
 bool QGalleryMetaDataFilter::isNegated() const
@@ -1026,7 +964,6 @@ bool QGalleryMetaDataFilter::isNegated() const
 
 /*!
     Sets whether the result of a meta-data filter should be \a negated.
-    \since 1.1
 */
 
 void QGalleryMetaDataFilter::setNegated(bool negated)
@@ -1036,7 +973,6 @@ void QGalleryMetaDataFilter::setNegated(bool negated)
 
 /*!
     Returns a meta-data filter which tests the negation of an existing filter.
-    \since 1.1
 */
 
 QGalleryMetaDataFilter QGalleryMetaDataFilter::operator !() const
@@ -1051,7 +987,6 @@ QGalleryMetaDataFilter QGalleryMetaDataFilter::operator !() const
 
     \ingroup gallery
     \ingroup gallery-filters
-    \since 1.1
 
     \inmodule QtGallery
 
@@ -1116,7 +1051,6 @@ QGalleryFilter::QGalleryFilter()
 
 /*!
     Constructs a copy of a gallery \a filter.
-    \since 1.1
 */
 
 QGalleryFilter::QGalleryFilter(const QGalleryFilter &filter)
@@ -1126,7 +1060,6 @@ QGalleryFilter::QGalleryFilter(const QGalleryFilter &filter)
 
 /*!
     Constructs a copy of a gallery intersection \a filter.
-    \since 1.1
 */
 
 QGalleryFilter::QGalleryFilter(const QGalleryIntersectionFilter &filter)
@@ -1136,7 +1069,6 @@ QGalleryFilter::QGalleryFilter(const QGalleryIntersectionFilter &filter)
 
 /*!
     Constructs a copy of a gallery union \a filter.
-    \since 1.1
 */
 
 QGalleryFilter::QGalleryFilter(const QGalleryUnionFilter &filter)
@@ -1146,7 +1078,6 @@ QGalleryFilter::QGalleryFilter(const QGalleryUnionFilter &filter)
 
 /*!
     Constructs a copy of a gallery meta-data \a filter.
-    \since 1.1
 */
 
 QGalleryFilter::QGalleryFilter(const QGalleryMetaDataFilter &filter)
@@ -1164,7 +1095,6 @@ QGalleryFilter::~QGalleryFilter()
 
 /*!
     Assigns the value of \a filter to another filter.
-    \since 1.1
 */
 
 QGalleryFilter &QGalleryFilter::operator =(const QGalleryFilter &filter)
@@ -1176,7 +1106,6 @@ QGalleryFilter &QGalleryFilter::operator =(const QGalleryFilter &filter)
 
 /*!
     Returns the type of a filter.
-    \since 1.1
 */
 
 QGalleryFilter::Type QGalleryFilter::type() const
@@ -1186,7 +1115,6 @@ QGalleryFilter::Type QGalleryFilter::type() const
 
 /*!
     Returns true if the type() of the filter is not equal to Invalid.
-    \since 1.1
 */
 
 bool QGalleryFilter::isValid() const
@@ -1199,7 +1127,6 @@ bool QGalleryFilter::isValid() const
     Intersection or this will return an Invalid filter.
 
     Returns a QGalleryIntersectionFilter.
-    \since 1.1
 */
 
 QGalleryIntersectionFilter QGalleryFilter::toIntersectionFilter() const
@@ -1214,7 +1141,6 @@ QGalleryIntersectionFilter QGalleryFilter::toIntersectionFilter() const
     will return an Invalid filter.
 
     Returns a QGalleryUnionFilter.
-    \since 1.1
 */
 
 QGalleryUnionFilter QGalleryFilter::toUnionFilter() const
@@ -1229,7 +1155,6 @@ QGalleryUnionFilter QGalleryFilter::toUnionFilter() const
     or this will return an Invalid filter.
 
     Returns a QGalleryMetaDataFilter.
-    \since 1.1
 */
 
 QGalleryMetaDataFilter QGalleryFilter::toMetaDataFilter() const
@@ -1252,7 +1177,6 @@ QDebug operator <<(QDebug debug, const QGalleryFilter &filter)
     Compares \a filter1 to filter2.
 
     Returns true if the filters are identical, and false otherwise.
-    \since 1.1
 */
 
 bool operator ==(const QGalleryFilter &filter1, const QGalleryFilter &filter2)
@@ -1264,7 +1188,6 @@ bool operator ==(const QGalleryFilter &filter1, const QGalleryFilter &filter2)
     Compares \a filter1 to filter2.
 
     Returns true if the filters are not identical, and false otherwise.
-    \since 1.1
 */
 
 bool operator !=(const QGalleryFilter &filter1, const QGalleryFilter &filter2)
